@@ -66,9 +66,9 @@ class Estimator(AbstractEstimator):
     @lru_cache()
     def estimate(self, design_point: Tuple[int, ...], metric: Metric) -> float:
         if self.__regression_model is RegressionModel.KERNEL_RIDGE:
-            estimate = self.__kernel_ridge(design_point, metric)
+            estimate = self.__kernel_ridge(list(design_point), metric)
         elif self.__regression_model is RegressionModel.STREAM_LEARNING:
-            estimate = self.__stream_learner(design_point, metric)
+            estimate = self.__stream_learner(list(design_point), metric)
         else:
             raise Exception(
                 "Learinig method "
@@ -101,7 +101,7 @@ class Estimator(AbstractEstimator):
         return estimate
 
     def __prepare_data(
-        self, design_point: Tuple[int, ...], metric: Optional[Metric] = None,
+        self, design_point: List[int], metric: Optional[Metric] = None,
     ):
         X = self.__get_independent_variables()
         X = X.astype("int64").reshape(-1, len(design_point))
@@ -119,7 +119,7 @@ class Estimator(AbstractEstimator):
         return X, y
 
     def __stream_learner(
-        self, design_point: Tuple[int, ...], metric: Metric
+        self, design_point: List[int], metric: Metric
     ) -> float:
         X, y = None, None
         if self.__last_design_point != design_point:
@@ -135,9 +135,9 @@ class Estimator(AbstractEstimator):
             if self.__last_len != len(X):
                 Xl = X[-1]
                 yl = y[-1]
-                Xl.astype("int64").reshape(1, len(design_point))
+                Xl = Xl.astype("int64").reshape(1, len(design_point))
                 if self.__metrics:
-                    yl.astype("float64").reshape(1, len(self.__metrics))
+                    yl = yl.astype("float64").reshape(1, len(self.__metrics))
                 else:
                     raise Exception(
                         "Metrics not initialized while partially fitting streaming learner"
@@ -150,9 +150,7 @@ class Estimator(AbstractEstimator):
             self.__metrics.index(metric)
         ]
 
-    def __kernel_ridge(
-        self, design_point: Tuple[int, ...], metric: Metric
-    ) -> float:
+    def __kernel_ridge(self, design_point: List[int], metric: Metric) -> float:
         X, y = None, None
         if self.__last_design_point != design_point:
             X, y = self.__prepare_data(design_point)
